@@ -17,6 +17,3 @@ def date_partition(max_partition: int) -> str:
     date_partition = ['dia', 'semana', 'mês', 'trimestre', 'semestre', 'ano']
     return f'por {choice(date_partition[:max_partition])}'
 
-
-for i in range(100):
-    print(date_partition(3))
